"""
https://poe.com/chat/3e1jw21901csun1xix4






async def set_location(latitude, longitude):
    browser = await launch()
    page = await browser.newPage()

    # 设置地理位置
    await page.emulateMediaFeatures([{
        'name': 'geolocation',
        'value': f'{{ "latitude": {latitude}, "longitude": {longitude} }}'
    }])

    # 导航到需要的页面
    await page.goto('https://www.example.com')

    # 执行其他操作...

    await browser.close()


# 调用函数设置位置
await set_location(37.7749, -122.4194)  # 设置位置为旧金山"

"""



from dataclasses import dataclass

from .class_base import class_base


class colors(metaclass=class_base):
    """ EXPLAIN :   系统颜色
        PARAMS  :   参数
                    red = '\033[31m'  # 红色  用途_日志错误
                    green = '\033[32m'  # 绿色
                    yellow = '\033[33m'  # 黄色
                    purple = '\033[35m'  # 紫色
                    cyan = '\033[36m'  # 青色   用途_日志正确
                    end = '\033[0m'  # 结束
        RETURN  :   null
        EXAMPLE :   print("color.red             :", color.red, 1111)
    """
    red = '\033[31m'  # 红色  用途_日志错误
    green = '\033[32m'  # 绿色
    yellow = '\033[33m'  # 黄色
    purple = '\033[35m'  # 紫色
    cyan = '\033[36m'  # 青色   用途_日志正确
    end = '\033[0m'  # 结束

    # # 文本输出
    # def __repr__(self):
    #     # return f"{{{', '.join(f'{k}={v}' for k, v in self.__class__.__dict__.items() if not k.startswith('__'))}}}"
    #     parts = []
    #     for k, v in self.__class__.__dict__.items():
    #         if not k.startswith('__'):
    #             parts.append(f"{k}={v}")
    #     return f"{{{', '.join(parts)}}}"


if __name__ == '__main__':
    print("color                 :", colors)
    print("color.red             :", colors.red, 1111)



import asyncio
from pyppeteer import launch

import win32api, win32gui, win32con  # pip  install     pywin32  可能会出现问题_请看README_后端py.md

__ = None

import astmain_py777.astmain as __  # 本地包

if __name__ == '__main__':
    pass


    async def aaa():
        pass
        opt = dict(
            title="小许",
            text="1111",
            files=[r"C:\Users\Administrator\Desktop\111.png", r"C:\Users\Administrator\Desktop\222.png"],
            cookies_str="""[
    {
        "name": "acw_tc",
        "value": "154f43315f9dd63775e16408461fa4c82934e714470824df342755d810f2dd0d",
        "domain": "www.xiaohongshu.com",
        "hostOnly": true,
        "path": "/",
        "secure": false,
        "httpOnly": true,
        "session": false,
        "expirationDate": 1719508892.862441,
        "sameSite": "unspecified"
    },
    {
        "name": "abRequestId",
        "value": "a376129c-d49b-5bbc-a8f4-170cc4bfe129",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1751043092.862638,
        "sameSite": "unspecified"
    },
    {
        "name": "a1",
        "value": "1905a9c0831wg416b0zniax0jqghkn390f4cocqpf50000243666",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1751043093,
        "sameSite": "unspecified"
    },
    {
        "name": "webId",
        "value": "6e110199fae6482d9b9f8ba843732d83",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1751043093,
        "sameSite": "unspecified"
    },
    {
        "name": "websectiga",
        "value": "984412fef754c018e472127b8effd174be8a5d51061c991aadd200c69a2801d6",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1719766294,
        "sameSite": "unspecified"
    },
    {
        "name": "sec_poison_id",
        "value": "f4fa6476-d599-4d89-8c13-d2096c48a76b",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1719507699,
        "sameSite": "unspecified"
    },
    {
        "name": "gid",
        "value": "yj820jSJyW8Dyj820jS8YiSAqyEk4yKD8uI34Ui0C8VAkS28xTIqjl888J4qKKK8yKqfJWW8",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1754067249.237062,
        "sameSite": "unspecified"
    },
    {
        "name": "xsecappid",
        "value": "xhs-pc-web",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1751043246,
        "sameSite": "unspecified"
    },
    {
        "name": "web_session",
        "value": "0400698e30a4ad561bd2b1d048344bd1202e4a",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": true,
        "httpOnly": true,
        "session": false,
        "expirationDate": 1751043156.445488,
        "sameSite": "unspecified"
    },
    {
        "name": "webBuild",
        "value": "4.23.1",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": true,
        "sameSite": "unspecified"
    }
]""",
        )

        opt = __.to_obj_dict(opt)

        # spider = await spider_pyppeteer()
        # spider = await __.spider.spider_pyppeteer(**dict( x=300, y=1))
        # spider = await __.spider.spider_pyppeteer(**dict(x=0, y=-900 + 2))
        spider = await __.spider.spider_pyppeteer(**dict(x=-1800, y=-900 + 999))
        page = spider.page
        # cookies登陆
        # await spider.web_goto_set_cookie("https://creator.xiaohongshu.com/publish/publish", __.to.JSON(opt.cookies_str))
        # await spider.web_goto_set_cookie("https://creator.xiaohongshu.com", __.to.JSON(opt.cookies_str))
        await spider.web_goto_set_cookie("https://creator.xiaohongshu.com/publish/publish", __.to.JSON(opt.cookies_str))
        await __.tool_await(1)

        # 点击发布图文
        await spider.web_await_click(css=".tab:nth-child(2)")
        await spider.web_await_input_files(css=".upload-input", files=opt.files)

        # 输入标题
        await spider.web_await_input_text(css=".titleInput .el-input__wrapper .el-input__inner", text=opt.title)

        # 输入描述
        await spider.web_await_input_text(css=".topic-container", text=opt.text)

        # 添加地点
        pass

        # 权限设置_私密
        await spider.web_await_click(css=".el-radio__label")

        # 发布_按钮点击
        await spider.web_await_click(css=".publishBtn")

        # 判断_是否_成功
        await spider.web_await_css(css=".btn-content")
        html = await page.content()

        await __.tool_await(0.1)
        await __.tool_await(9999)
        await spider.browser.close()
        print("成功:发布内容---关闭浏览器---xiaohongshu")


    asyncio.get_event_loop().run_until_complete(aaa())



import builtins

old_print = print

is_debugger = False


def log(*args, **kwargs):
    old_print(*args, **kwargs)


# 替换内置的 print 函数


builtins.print = log

# 使用自定义的 print 函数
print("Hello, world!")
print("This is a test.", "Additional message.", sep="-")



import ctypes


def win_hide_taskbar(hwnd: int) -> None:
    """
    设置隐藏程序的任务栏


    code
    print("result                 :", wind_set_taskbar_hide("Goog"))
    """
    # 隐藏任务栏
    window_style = ctypes.windll.user32.GetWindowLongW(hwnd, -16)  # -16 代表 GWL_STYLE
    window_style &= ~0x10000000  # 清除 WS_VISIBLE 标志位
    ctypes.windll.user32.SetWindowLongW(hwnd, -16, window_style)
    result = ctypes.windll.user32.SetWindowPos(hwnd, None, 100, -880, 0, 0, 0x0001)
    return result
    """
    好博客 https://blog.csdn.net/weixin_30314631/article/details/97574375
    hwnd 是要移动的窗口的句柄。
    hWndInsertAfter 设为 None 表示不改变窗口的插入顺序。
    x 和 y 设置为 100,表示将窗口的左上角移动到屏幕坐标 (100, 100)。
    cx 和 cy 设为 0 表示不改变窗口的大小。
    uFlags 设为 0x0001 表示只修改窗口的位置,不修改大小。
    """


if __name__ == '__main__':
    print("result                 :", win_hide_taskbar("Goog"))



import os



def find_file(root_dir, filename):
    """在给定的根目录中搜索指定的文件名,并返回文件的绝对路径。 如果找到文件,返回文件路径;否则返回 None。 """
    file_path = os.path.join(root_dir, filename)
    if os.path.exists(file_path):
        return file_path
    for dirpath, dirnames, filenames in os.walk(root_dir):
        for file in filenames:
            if file.lower() == filename.lower():
                return os.path.join(dirpath, file)
    return None


def fs_find_file(dirs, filenames):
    """
    根据给定的目录列表和文件名列表,搜索并返回找到的第一个文件的绝对路径。
    如果找到任何文件,则返回文件的绝对路径,否则返回 None。

    示例:
    dirs = ['C:\\Program Files (x86)', 'C:\\Program Files', 'C:\\']
    filenames = ['chrome.exe', 'notepad.exe']
    file_path = fs_find_file(dirs, filenames)
    """
    for root_dir in dirs:
        for filename in filenames:
            file_path = find_file(root_dir, filename)
            if file_path is not None:
                # return file_path
                return file_path.replace('\\', '/')
    return None


def main():
    dirs = ['C:\\Program Files (x86)', 'C:/Program Files', 'C:/']
    filenames = ['chrome.exe']
    file_path = fs_find_file(dirs, filenames)
    if file_path:
        print(f'Found file at: {file_path}')
    else:
        print(f'Files not found.')


if __name__ == '__main__':
    main()

    # 不要使用列表推导式#不要使用lambda表达式#运行速度在快一点,我写好正文注释
    # 不要使用multiprocessing    进程的方式
    # 不要使用 async await       的方式
    # 帮我封装一下

    """






"""
